# Natural Language Qu Kit (NLQK)

(C) 2024-2025 by [Damir Cavar], [NLP-Lab]


Natural Language Qu Kit (NLQK) is a toolkit for Quantum Natural Language Processing (Q-NLP).

This is an [Natural Language Processing Lab] project.

What is the goal of this project?

The goals are to provide a library and programming environment for Natural Language Processing using a hybrid environment of classical and quantum computers. NLP tools and libraries are excellent environments for education or deployed NLP applications:

- [Natural Language Processing Toolkit](https://www.nltk.org/)
- [spaCy](https://spacy.io/)

There are some excellent Q-NLP libraries and tools as for example:

- [lambeq](https://github.com/CQCL/lambeq)

We aim at expanding these development environments (classical and quantum) to facilitate Quantum NLP engineering.



## Links

- [NLQK.ai](http://nlqk.ai/)
- [NLQK PyPi page](https://pypi.org/project/nlqk/)
- [NLP-Lab]
- [NLP-Lab Quantum NLP](https://nlp-lab.org/quantumnlp/)


## Install

Use PyPi

  pip install nlqk



## Contributors

- [Dr. Damir Cavar]
- [Billy Dickson]
- [Koushik Reddy Parukola]



[Damir Cavar]: http://damir.cavar.me/ "Damir Cavar"
[NLP-Lab]: https://nlp-lab.org/ "NLP Lab"
[Billy Dickson]: https://www.linkedin.com/in/billy-dickson/ "Billy Dickson"
[Koushik Reddy Parukola]: https://www.linkedin.com/in/koushik-reddy-parukola/ "Koushik Reddy Parukola"
[Dr. Damir Cavar]: https://luddy.indiana.edu/contact/profile/?Damir_Cavar "Damir Cavar"
[NLP-Lab]: https://nlp-lab.org/ "Natural Language Processing Lab"
[Natural Language Processing Lab]: https://nlp-lab.org/ "Natural Language Processing Lab"
[NLQK.ai]: http://nlqk.ai/ "NLQK.ai"

